@@ -50,8 +50,9 @@
 
 #include "xfce-icontheme.h"
 
-#define DEFAULT_THEME "Rodent"
-#define SIZE_THRESHOLD_BELOW 20  /* tweak this if we get ugly upscaled icons */
+#define DEFAULT_THEME         "Rodent"
+#define SIZE_THRESHOLD_BELOW  20  /* tweak this if we get ugly upscaled icons */
+#define FALLBACK_INDEX        DATADIR "/xfce4/hicolor-index.theme"
 
 typedef struct
 {
@@ -108,23 +109,23 @@ static gboolean _gdk_pixbuf_has_svg = FALSE;
 
 static const gchar *builtin_icon_categories[][XFCE_N_BUILTIN_ICON_CATEGORIES] =
 {
-	{ "xfce-unknown", "gnome-fs-executable", "exec", NULL },
-	{ "xfce-edit", "gedit-icon", "edit", NULL },
-	{ "xfce-filemanager", "file-manager", "folder", NULL },
-	{ "xfce-utils", "gnome-util", "utilities", NULL },
-	{ "xfce-games", "gnome-joystick", "games", NULL },
-	{ "xfce-man", "gnome-help", "help", NULL },
-	{ "xfce-multimedia", "gnome-multimedia", "multimedia", NULL },
-	{ "xfce-internet", "gnome-globe", "web-browser", NULL },
-	{ "xfce-graphics", "gnome-graphics", "graphics", NULL },
-	{ "xfce-printer", "gnome-dev-printer", "printer", NULL },
-	{ "xfce-schedule", "gnome-month", "productivity", NULL },
-	{ "xfce-sound", "gnome-audio", "sound", NULL },
-	{ "xfce-terminal", "gnome-terminal", "terminal", NULL },
-	{ "xfce-devel", "gnome-devel", NULL },
-	{ "xfce-settings", "gnome-settings", NULL },
-	{ "xfce-system", "gnome-system", NULL },
-	{ "xfce-wine", "wine", NULL }
+	{ "xfce-unknown", "gnome-fs-executable", "exec", "emblem-generic", NULL, NULL },
+	{ "xfce-edit", "gedit-icon", "edit", NULL, NULL, NULL },
+	{ "xfce-filemanager", "file-manager", "folder", NULL, NULL, NULL },
+	{ "xfce-utils", "gnome-util", "utilities", NULL, NULL, NULL },
+	{ "xfce-games", "gnome-joystick", "games", "emblem-fun", NULL, NULL },
+	{ "xfce-man", "gnome-help", "help", NULL, NULL, NULL },
+	{ "xfce-multimedia", "gnome-multimedia", "multimedia", "emblem-multimedia", NULL, NULL },
+	{ "xfce-internet", "gnome-globe", "gnome-fs-network", "web-browser", "emblem-web", NULL },
+	{ "xfce-graphics", "gnome-graphics", "graphics", NULL, NULL, NULL },
+	{ "xfce-printer", "gnome-dev-printer", "printer", NULL, NULL, NULL },
+	{ "xfce-schedule", "gnome-month", "productivity", "emblem-documents", NULL, NULL },
+	{ "xfce-sound", "gnome-audio", "sound", NULL, NULL, NULL },
+	{ "xfce-terminal", "gnome-terminal", "terminal", NULL, NULL, NULL },
+	{ "xfce-devel", "gnome-devel", NULL, NULL, NULL },
+	{ "xfce-settings", "gnome-settings", NULL, NULL, NULL },
+	{ "xfce-system", "gnome-system", NULL, NULL, NULL },
+	{ "xfce-wine", "wine", NULL, NULL, NULL }
 };
 
 /* list in order of preference */
@@ -197,6 +198,13 @@ theme_add_all(XfceIconThemeSingleton *singleton, const gchar *base_path,
 		icon_ext = icon_ext_without_svg;
 	
 	themerc = xfce_rc_simple_open(buf, TRUE);
+    if(!themerc && !g_ascii_strcasecmp(theme_name, "hicolor")
+            && (p = g_strrstr(buf, "/")))
+    {
+        *p = 0;
+        if(g_file_test(buf, G_FILE_TEST_IS_DIR))
+            themerc = xfce_rc_simple_open(FALLBACK_INDEX, TRUE);
+    }
 	if(themerc) {
 		if(xfce_rc_has_group(themerc, "Icon Theme")) {
 			xfce_rc_set_group(themerc, "Icon Theme");
